@@ -1,13 +1,22 @@
-from manim import *
+import sys
+
+import git
+import manim as m
+
 from git_sim.git_sim_base_command import GitSimBaseCommand
-import git, sys, numpy
+
 
 class GitSimAdd(GitSimBaseCommand):
     def __init__(self, scene):
         super().__init__(scene)
         self.maxrefs = 2
-        self.selected_branches.append(self.repo.active_branch.name)
         self.hide_first_tag = True
+        self.allow_no_commits = True
+
+        try:
+            self.selected_branches.append(self.repo.active_branch.name)
+        except TypeError:
+            pass
 
         for name in self.scene.args.name:
             if name not in [x.a_path for x in self.repo.index.diff(None)] + [z for z in self.repo.untracked_files]:
@@ -35,11 +44,15 @@ class GitSimAdd(GitSimBaseCommand):
                 for name in self.scene.args.name:
                     if name == x.a_path:
                         thirdColumnFileNames.add(x.a_path)
-                        secondColumnArrowMap[x.a_path] = Arrow(stroke_width=3, color=self.scene.fontColor)
-
-        for y in self.repo.index.diff("HEAD"):
-            if "git-sim_media" not in y.a_path:
-                thirdColumnFileNames.add(y.a_path)
+                        secondColumnArrowMap[x.a_path] = m.Arrow(stroke_width=3, color=self.scene.fontColor)
+        try:
+            for y in self.repo.index.diff("HEAD"):
+                if "git-sim_media" not in y.a_path:
+                    thirdColumnFileNames.add(y.a_path)
+        except git.exc.BadName:
+            for (y, _stage), entry in self.repo.index.entries.items():
+                if "git-sim_media" not in y:
+                    thirdColumnFileNames.add(y)
 
         for z in self.repo.untracked_files:
             if "git-sim_media" not in z:
@@ -47,4 +60,4 @@ class GitSimAdd(GitSimBaseCommand):
                 for name in self.scene.args.name:
                     if name == z:
                         thirdColumnFileNames.add(z)
-                        firstColumnArrowMap[z] = Arrow(stroke_width=3, color=self.scene.fontColor)
+                        firstColumnArrowMap[z] = m.Arrow(stroke_width=3, color=self.scene.fontColor)
