@@ -1,6 +1,11 @@
-from manim import *
+import sys
+
+import git
+import manim as m
+import numpy
+
 from git_sim.git_sim_base_command import GitSimBaseCommand
-import git, sys, numpy
+
 
 class GitSimBranch(GitSimBaseCommand):
     def __init__(self, scene):
@@ -15,16 +20,16 @@ class GitSimBranch(GitSimBaseCommand):
         self.recenter_frame()
         self.scale_frame()
 
-        branchText = Text(self.scene.args.name, font="Monospace", font_size=20, color=self.scene.fontColor)
-        branchRec = Rectangle(color=GREEN, fill_color=GREEN, fill_opacity=0.25, height=0.4, width=branchText.width+0.25)
+        branchText = m.Text(self.scene.args.name, font="Monospace", font_size=20, color=self.scene.fontColor)
+        branchRec = m.Rectangle(color=m.GREEN, fill_color=m.GREEN, fill_opacity=0.25, height=0.4, width=branchText.width+0.25)
 
-        branchRec.next_to(self.topref, UP) 
+        branchRec.next_to(self.topref, m.UP)
         branchText.move_to(branchRec.get_center())
 
-        fullbranch = VGroup(branchRec, branchText)
+        fullbranch = m.VGroup(branchRec, branchText)
 
         if self.scene.args.animate:
-            self.scene.play(Create(fullbranch), run_time=1/self.scene.args.speed)
+            self.scene.play(m.Create(fullbranch), run_time=1/self.scene.args.speed)
         else:
             self.scene.add(fullbranch)
 
