@@ -1,13 +1,22 @@
-from manim import *
+import sys
+
+import git
+import manim as m
+import numpy
+
 from git_sim.git_sim_base_command import GitSimBaseCommand
-import git, sys, numpy
+
 
 class GitSimLog(GitSimBaseCommand):
     def __init__(self, scene):
         super().__init__(scene)
         self.numCommits = self.scene.args.commits
         self.defaultNumCommits = self.scene.args.commits
-        self.selected_branches.append(self.repo.active_branch.name)
+
+        try:
+            self.selected_branches.append(self.repo.active_branch.name)
+        except TypeError:
+            pass
 
     def execute(self):
         print("Simulating: git " + self.scene.args.subcommand)
